@@ -1,5 +1,6 @@
 import matplotlib.pyplot as plt
 import numpy as np
+import pandas as pd
 
 
 def fis_tool_clean_df_columns(df):
@@ -105,9 +106,9 @@ def fis_tools_strong_corr(df, lim_inf = 0.3, lim_sup = 1,drop_dupli=True):
     #Devuelve la salida
     return(c)
     
-def fis_tools_ranking_mi(mutual_selector, modo = 'tabla'):
+def fis_tools_ranking_mi(mutual_selector, modo = 'tabla', predictors_df):
     #Maqueta el ranking
-    ranking_mi = pd.DataFrame(mutual_selector, index = x.columns).reset_index()
+    ranking_mi = pd.DataFrame(mutual_selector, index = predictors_df.columns).reset_index()
     ranking_mi.columns = ['variable','importancia_mi']
     ranking_mi = ranking_mi.sort_values(by = 'importancia_mi', ascending = False)
     ranking_mi['ranking_mi'] = np.arange(0,ranking_mi.shape[0])
